<!--cut-->
<div class="inline cut">
    <img src="{{ request.static_url('sacrud:static/images/cut-26.png') }}" alt="cut object" height="18" width="18" style="cursor:pointer; padding-top:5px;">
</div>
