<select class="sacrud_select" name="{{ col.name }}">
  {% for x in session.query(cls) %}
  <option value='{{ x.id }}'
  {% if obj %}{% if getattr(obj, col.name)==x.id %}
    selected
  {% endif%}{% endif %}>
    {{ x.__repr__() }}
  </option>
  {% endfor %}
</select>  
